@@ -16,5 +16,8 @@ class TestCommon(object):
 	
 	def test_get_raw_data(self):
 		url = FLT_BASE+'ai101'
-		assert get_raw_data(url,'tblFlightData','tr').__len__() > 0		
+		assert get_raw_data(url,'tblFlightData','tr').__len__() > 0	
+		
+	def test_encode_and_get(self):
+		assert encode_and_get('test') is not None
 	
\ No newline at end of file
